package it.unibas.acim2pinco.controllo;

import java.util.ArrayList;
import java.util.List;
import it.unibas.pinco.utilita.Convalidatore;
import it.unibas.pinco.framework.Applicazione;
import it.unibas.acim2pinco.persistenza.DAOProprietario;
import it.unibas.acim2pinco.persistenza.DAOException;
import it.unibas.acim2pinco.modello.Proprietario;

public class FormProprietario {

    // codiceFiscale: esattamente 6 caratteri
    private String codiceFiscale = "";
    // nome: non nullo, deve contenere uno spazio
    private String nome = "";
    // cittaDiResidenza: qualsiasi valore e' accettabile
    private String cittaDiResidenza = "";
    // annoPatente: intero compreso tra 1920 e 2002
    private String annoPatente = "";

    public void setNome(String nome){
        this.nome = nome;
    }

    public void setCodiceFiscale(String codiceFiscale){
        this.codiceFiscale = codiceFiscale;
    }

    public void setCittaDiResidenza(String cittaDiResidenza){
        this.cittaDiResidenza = cittaDiResidenza;
    }

    public void setAnnoPatente(String annoPatente){
        this.annoPatente = annoPatente;
    }

    public String getNome(){
        return nome;
    }

    public String getCodiceFiscale(){
        return codiceFiscale;
    }

    public String getCittaDiResidenza(){
        return cittaDiResidenza;
    }

    public String getAnnoPatente() {
        return annoPatente;
    }

    public List convalida() {
        List errori = new ArrayList();
        Convalidatore.verificaStringaNonNulla(this.codiceFiscale, "codice fiscale", errori);
        Convalidatore.verificaLunghezzaStringa(this.codiceFiscale, 6, "codice fiscale", errori);
        if (errori.size() == 0) {
            try {
                Proprietario proprietario = DAOProprietario.doSelectCodiceFiscale(this.codiceFiscale);
                if (proprietario != null) {
                    errori.add("Errore: codice fiscale gia' esistente nella base di dati");
                }
            } catch (DAOException daoe) {
                Applicazione.logSevere("FormProprietario", "convalida", daoe + "");
            }
        }
        Convalidatore.verificaStringaNonNulla(this.nome, "nome", errori);
        if (this.nome != null && !this.nome.equals("") && this.nome.indexOf(" ") == -1) {
            errori.add("Errore nel valore del nome: il valore deve contenere nome e cognome");
        }
        Convalidatore.verificaInteroMinimo(this.annoPatente, 1920, "anno patente", errori);  
        return errori;
    }
}